@@ -5,7 +5,6 @@ from os.path import join
 
 
 def _getCredential(args, name, envVar, promptFunc):
-
     # Check if the credential was specified via the command-line
     if getattr(args, name, None) is not None:
         print("Using {} specified via `-{}` command-line argument.".format(name, name))
@@ -28,12 +27,14 @@ def _getUsername(args):
 
 def _getPassword(args):
     return _getCredential(
-        args, "password", "UE4DOCKER_PASSWORD", lambda: getpass.getpass("Password: ")
+        args,
+        "password",
+        "UE4DOCKER_PASSWORD",
+        lambda: getpass.getpass("Access token or password: "),
     )
 
 
 def build():
-
     # Create our logger to generate coloured output on stderr
     logger = Logger(prefix="[{} build] ".format(sys.argv[0]))
 
@@ -87,7 +88,6 @@ def build():
 
     # Create an auto-deleting temporary directory to hold our build context
     with tempfile.TemporaryDirectory() as tempDir:
-
         contextOrig = join(os.path.dirname(os.path.abspath(__file__)), "dockerfiles")
 
         # Create the builder instance to build the Docker images
@@ -161,7 +161,6 @@ def build():
 
         # Determine if we are building Windows or Linux containers
         if config.containerPlatform == "windows":
-
             # Provide the user with feedback so they are aware of the Windows-specific values being used
             logger.info("WINDOWS CONTAINER SETTINGS", False)
             logger.info(
@@ -300,7 +299,6 @@ def build():
 
         # Determine if we need to prompt for credentials
         if config.dryRun == True:
-
             # Don't bother prompting the user for any credentials during a dry run
             logger.info(
                 "Performing a dry run, `docker build` commands will be printed and not executed.",
@@ -310,7 +308,6 @@ def build():
             password = ""
 
         elif config.layoutDir is not None:
-
             # Don't bother prompting the user for any credentials when we're just copying the Dockerfiles to a directory
             logger.info(
                 "Copying generated Dockerfiles to: {}".format(config.layoutDir), False
@@ -322,7 +319,6 @@ def build():
             not config.buildTargets["source"]
             or builder.willBuild("ue4-source", mainTags) == False
         ):
-
             # Don't bother prompting the user for any credentials if we're not building the ue4-source image
             logger.info(
                 "Not building the ue4-source image, no Git credentials required.", False
@@ -331,7 +327,6 @@ def build():
             password = ""
 
         else:
-
             # Retrieve the Git username and password from the user when building the ue4-source image
             print(
                 "\nRetrieving the Git credentials that will be used to clone the UE4 repo"
@@ -349,7 +344,6 @@ def build():
         endpoint = None
 
         try:
-
             # Keep track of our starting time
             startTime = time.time()
 
@@ -417,13 +411,13 @@ def build():
             # Build the UE4 source image
             if config.buildTargets["source"]:
                 # Start the HTTP credential endpoint as a child process and wait for it to start
-                if config.opts.get("credential_mode", "endpoint") == "endpoint":
+                if config.opts["credential_mode"] == "endpoint":
                     endpoint = CredentialEndpoint(username, password)
                     endpoint.start()
 
                 # If we're using build secrets then pass the Git username and password to the UE4 source image as secrets
                 secrets = {}
-                if config.opts.get("credential_mode", "endpoint") == "secrets":
+                if config.opts["credential_mode"] == "secrets":
                     secrets = {"username": username, "password": password}
                 credentialArgs = [] if len(secrets) > 0 else endpoint.args()
 
@@ -470,7 +464,6 @@ def build():
 
             # Build the full UE4 CI image, unless requested otherwise by the user
             if config.buildTargets["full"]:
-
                 # If custom version strings were specified for ue4cli and/or conan-ue4cli, use them
                 infrastructureFlags = []
                 if config.ue4cliVersion is not None:
@@ -503,10 +496,8 @@ def build():
 
             # If we are generating Dockerfiles then include information about the options used to generate them
             if config.layoutDir is not None:
-
                 # Determine whether we generated a single combined Dockerfile or a set of Dockerfiles
                 if config.combine == True:
-
                     # Generate a comment to place at the top of the single combined Dockerfile
                     lines = [
                         "This file was generated by ue4-docker version {} with the following options:".format(
@@ -547,7 +538,6 @@ def build():
                     FilesystemUtils.writeFile(dockerfile, dockerfileContents)
 
                 else:
-
                     # Create a JSON file to accompany the set of generated Dockerfiles
                     FilesystemUtils.writeFile(
                         join(config.layoutDir, "generated.json"),
@@ -578,7 +568,6 @@ def build():
                 endpoint.stop()
 
         except (Exception, KeyboardInterrupt) as e:
-
             # One of the images failed to build
             logger.error("Error: {}".format(e))
             resourceMonitor.stop()
