@@ -38,6 +38,7 @@ UNREAL_ENGINE_RELEASE_CHANGELISTS = {
     "4.26.0": 14830424,
     "4.27.0": 17155196,
     "5.0.0": 19505902,
+    "5.1.0": 23058290,
 }
 
 
@@ -52,16 +53,20 @@ class VisualStudio(object):
         VS2022: "17",
     }
 
-    MinSupportedUnreal = {
+    SupportedSince = {
+        # We do not support versions older than 4.20
+        VS2017: semver.VersionInfo(4.20),
         # Unreal Engine 4.23.1 is the first that successfully builds with Visual Studio v16.3
         # See https://github.com/EpicGames/UnrealEngine/commit/2510d4fd07a35ba5bff6ac2c7becaa6e8b7f11fa
         #
         # Unreal Engine 4.25 is the first that works with .NET SDK 4.7+
         # See https://github.com/EpicGames/UnrealEngine/commit/5256eedbdef30212ab69fdf4c09e898098959683
         VS2019: semver.VersionInfo(4, 25),
-        VS2022: semver.VersionInfo(4, 27),
+        VS2022: semver.VersionInfo(5, 0, 0),
     }
 
+    UnsupportedSince = {VS2017: semver.VersionInfo(5, 0)}
+
 
 class ExcludedComponent(object):
     """
@@ -180,7 +185,7 @@ class BuildConfiguration(object):
         parser.add_argument(
             "-password",
             default=None,
-            help="Specify the password or access token to use when cloning the git repository",
+            help="Specify access token or password to use when cloning the git repository",
         )
         parser.add_argument(
             "-repo",
@@ -381,7 +386,6 @@ class BuildConfiguration(object):
             # Determine if we are building a custom version of UE4 rather than an official release
             self.args.release = self.args.release.lower()
             if self.args.release == "custom" or self.args.release.startswith("custom:"):
-
                 # Both a custom repository and a custom branch/tag must be specified
                 if self.args.repo is None or self.args.branch is None:
                     raise RuntimeError(
@@ -400,7 +404,6 @@ class BuildConfiguration(object):
                 self.custom = True
 
             else:
-
                 # Validate the specified version string
                 try:
                     ue4Version = semver.parse(self.args.release)
@@ -501,13 +504,19 @@ class BuildConfiguration(object):
                     )
                 )
 
+            if "credential_mode" not in self.opts:
+                # On Linux, default to secrets mode that causes fewer issues with firewalls
+                self.opts = (
+                    "secrets" if self.containerPlatform == "linux" else "endpoint"
+                )
+
             # Verify that the value for `credential_mode` is valid if specified
             validCredentialModes = (
                 ["endpoint", "secrets"]
                 if self.containerPlatform == "linux"
                 else ["endpoint"]
             )
-            if self.opts.get("credential_mode", "endpoint") not in validCredentialModes:
+            if self.opts["credential_mode"] not in validCredentialModes:
                 raise RuntimeError(
                     "invalid value specified for the `credential_mode` option, valid values are {} when building {} containers".format(
                         validCredentialModes, self.containerPlatform.title()
@@ -521,6 +530,13 @@ class BuildConfiguration(object):
             "templates": ExcludedComponent.Templates in self.excludedComponents,
         }
 
+        if "gitdependencies_args" not in self.opts:
+            self.opts["gitdependencies_args"] = (
+                "--exclude=Android --exclude=Mac --exclude=Linux"
+                if self.containerPlatform == "windows"
+                else "--exclude=Android --exclude=Mac --exclude=Win32 --exclude=Win64"
+            )
+
         # Warn user that they are in danger of Docker 20GB COPY bug
         # Unfortunately, we don't have a cheap way to check whether user environment is affected
         # See https://github.com/adamrehn/ue4-docker/issues/99
@@ -575,16 +591,27 @@ class BuildConfiguration(object):
 
         if self.release is not None and not self.custom:
             # Check whether specified Unreal Engine release is compatible with specified Visual Studio
-            vsMinSupportedUnreal = VisualStudio.MinSupportedUnreal.get(
+            supportedSince = VisualStudio.SupportedSince.get(self.visualStudio, None)
+            if (
+                supportedSince is not None
+                and semver.VersionInfo.parse(self.release) < supportedSince
+            ):
+                raise RuntimeError(
+                    "specified version of Unreal Engine is too old for Visual Studio {}".format(
+                        self.visualStudio
+                    )
+                )
+
+            unsupportedSince = VisualStudio.UnsupportedSince.get(
                 self.visualStudio, None
             )
             if (
-                vsMinSupportedUnreal is not None
-                and semver.VersionInfo.parse(self.release) < vsMinSupportedUnreal
+                unsupportedSince is not None
+                and semver.VersionInfo.parse(self.release) >= unsupportedSince
             ):
                 raise RuntimeError(
-                    "specified version of Unreal Engine cannot be built with Visual Studio {}, oldest supported is {}".format(
-                        self.visualStudio, vsMinSupportedUnreal
+                    "Visual Studio {} is too old for specified version of Unreal Engine".format(
+                        self.visualStudio
                     )
                 )
 
@@ -619,7 +646,6 @@ class BuildConfiguration(object):
         if self.args.isolation is not None:
             self.isolation = self.args.isolation
         else:
-
             # If we are able to use process isolation mode then use it, otherwise use Hyper-V isolation mode
             differentKernels = self.basetag != self.hostBasetag
             dockerSupportsProcess = parse_version(
@@ -643,7 +669,6 @@ class BuildConfiguration(object):
             except:
                 raise RuntimeError('invalid memory limit "{}"'.format(self.args.m))
         else:
-
             # Only specify a memory limit when using Hyper-V isolation mode, in order to override the 1GB default limit
             # (Process isolation mode does not impose any memory limits by default)
             if self.isolation == "hyperv":
@@ -660,7 +685,6 @@ class BuildConfiguration(object):
             self.platformArgs.extend(["-m", "{:.2f}GB".format(self.memLimit)])
 
     def _generateLinuxConfig(self):
-
         # Verify that any user-specified tag suffix does not collide with our base tags
         if self.suffix.startswith("opengl") or self.suffix.startswith("cudagl"):
             raise RuntimeError('tag suffix cannot begin with "opengl" or "cudagl".')
@@ -668,7 +692,6 @@ class BuildConfiguration(object):
         # Determine if we are building CUDA-enabled container images
         self.cuda = None
         if self.args.cuda is not None:
-
             # Verify that the specified CUDA version is valid
             self.cuda = self.args.cuda if self.args.cuda != "" else DEFAULT_CUDA_VERSION
             # Use the appropriate base image for the specified CUDA version
@@ -686,7 +709,6 @@ class BuildConfiguration(object):
         )
 
     def _processPackageVersion(self, package, version):
-
         # Leave the version value unmodified if a blank version was specified or a fully-qualified version was specified
         # (e.g. package==X.X.X, package>=X.X.X, git+https://url/for/package/repo.git, etc.)
         if version is None or "/" in version or version.lower().startswith(package):
@@ -700,7 +722,6 @@ class BuildConfiguration(object):
         return "{}=={}".format(package, version)
 
     def _processTemplateValue(self, value):
-
         # If the value is a boolean (either raw or represented by zero or one) then parse it
         if value.lower() in ["true", "1"]:
             return True
